==> cloudt-boot-starter-auth-provider-3.2.4.19-20230614.055437-2-sources.jar: com/elitescloud/boot/auth/provider/config/servlet/ServletSingleConfig.java <==
package com.elitescloud.boot.auth.provider.config.servlet;

import com.elitescloud.boot.auth.client.config.AuthorizationProperties;
import com.elitescloud.boot.auth.client.config.security.AbstractServletSecurityConfig;
import com.elitescloud.boot.auth.client.config.security.handler.DelegateAuthenticationCallable;
import com.elitescloud.boot.auth.provider.config.LoginSupportConfig;
import com.elitescloud.boot.auth.provider.security.configurer.LoginFilterSecurityConfigurer;
import com.elitescloud.boot.auth.provider.security.configurer.support.LoginFilterCustomizer;
import com.elitescloud.boot.auth.provider.security.generator.token.TokenGenerator;
import com.elitescloud.boot.auth.provider.security.handler.DefaultAuthenticationFailureHandler;
import com.elitescloud.boot.auth.provider.security.handler.JwtAuthenticationSuccessHandler;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.ObjectProvider;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Import;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.web.SecurityFilterChain;

/**
 * 单体认证方式.
 *
 * @author Kaiser（wang shao）
 * @date 2022/6/20
 */
@Log4j2
@ConditionalOnProperty(prefix = AuthorizationProperties.CONFIG_PREFIX, name = "type", havingValue = "single")
@ConditionalOnWebApplication(type = ConditionalOnWebApplication.Type.SERVLET)
@Import({LoginSupportConfig.class})
public class ServletSingleConfig extends AbstractServletSecurityConfig {
    private ObjectProvider<LoginFilterCustomizer<HttpSecurity>> loginFilterCustomizers;
    private TokenGenerator tokenGenerator;

    @Bean(SECURITY_CHAIN_DEFAULT)
    @ConditionalOnMissingBean(name = SECURITY_CHAIN_DEFAULT)
    public SecurityFilterChain defaultSecurityFilterChain(HttpSecurity http) throws Exception {
        var successHandler = new JwtAuthenticationSuccessHandler(authorizationProperties, DelegateAuthenticationCallable.getInstance(),
                tokenGenerator);

        super.defaultSecurityConfig(http)
                .apply(new LoginFilterSecurityConfigurer<>(loginFilterCustomizers))
                .successHandler(successHandler)
                .failureHandler(new DefaultAuthenticationFailureHandler(DelegateAuthenticationCallable.getInstance()))
        ;

        return http.build();
    }

    @Autowired
    public void setLoginFilterCustomizers(ObjectProvider<LoginFilterCustomizer<HttpSecurity>> loginFilterCustomizers) {
        this.loginFilterCustomizers = loginFilterCustomizers;
    }

    @Autowired
    public void setTokenGenerator(TokenGenerator tokenGenerator) {
        this.tokenGenerator = tokenGenerator;
    }
}

==> cloudt-boot-starter-auth-provider-3.4.5-20251031.105012-1-sources.jar: com/elitescloud/boot/auth/provider/config/servlet/ServletSingleConfig.java <==
package com.elitescloud.boot.auth.provider.config.servlet;

import com.elitescloud.boot.auth.client.config.AuthorizationProperties;
import com.elitescloud.boot.auth.client.config.security.AbstractServletSecurityConfig;
import com.elitescloud.boot.auth.client.config.security.handler.DelegateAuthenticationCallable;
import com.elitescloud.boot.auth.client.tool.RedisHelper;
import com.elitescloud.boot.auth.provider.config.LoginSupportConfig;
import com.elitescloud.boot.auth.provider.provider.user.UserDetailManager;
import com.elitescloud.boot.auth.provider.security.configurer.LoginFilterSecurityConfigurer;
import com.elitescloud.boot.auth.provider.security.configurer.support.LoginFilterCustomizer;
import com.elitescloud.boot.auth.provider.security.generator.token.TokenGenerator;
import com.elitescloud.boot.auth.provider.security.handler.DefaultAuthenticationFailureHandler;
import com.elitescloud.boot.auth.provider.security.handler.JwtAuthenticationSuccessHandler;
import com.elitescloud.boot.auth.provider.security.rememberme.RedisRememberMeTokenRepository;
import com.elitescloud.boot.auth.provider.security.rememberme.RememberMeUserDetailService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.ObjectProvider;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Import;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.web.SecurityFilterChain;

/**
 * 单体认证方式.
 *
 * @author Kaiser（wang shao）
 * @date 2022/6/20
 */
@Log4j2
@ConditionalOnProperty(prefix = AuthorizationProperties.CONFIG_PREFIX, name = "type", havingValue = "single")
@ConditionalOnWebApplication(type = ConditionalOnWebApplication.Type.SERVLET)
@Import({LoginSupportConfig.class})
public class ServletSingleConfig extends AbstractServletSecurityConfig {
    private ObjectProvider<LoginFilterCustomizer<HttpSecurity>> loginFilterCustomizers;
    private TokenGenerator tokenGenerator;
    private RedisHelper redisHelper;
    private UserDetailManager userDetailManager;

    @Bean(SECURITY_CHAIN_DEFAULT)
    @ConditionalOnMissingBean(name = SECURITY_CHAIN_DEFAULT)
    public SecurityFilterChain defaultSecurityFilterChain(HttpSecurity http) throws Exception {
        var successHandler = new JwtAuthenticationSuccessHandler(authorizationProperties, DelegateAuthenticationCallable.getInstance(),
                tokenGenerator);

        super.defaultSecurityConfig(http)
                .apply(new LoginFilterSecurityConfigurer<>(loginFilterCustomizers))
                .successHandler(successHandler)
                .failureHandler(new DefaultAuthenticationFailureHandler(DelegateAuthenticationCallable.getInstance()))
        ;

        // 记住我
        var rememberMe = super.rememberMeConfigurerCustomizer(new RedisRememberMeTokenRepository(redisHelper, (int) authorizationProperties.getRememberMeTtl().toSeconds())
                , new RememberMeUserDetailService(userDetailManager), successHandler);
        if (rememberMe != null) {
            http.rememberMe(rememberMe);
        }

        return http.build();
    }

    @Autowired
    public void setLoginFilterCustomizers(ObjectProvider<LoginFilterCustomizer<HttpSecurity>> loginFilterCustomizers) {
        this.loginFilterCustomizers = loginFilterCustomizers;
    }

    @Autowired
    public void setTokenGenerator(TokenGenerator tokenGenerator) {
        this.tokenGenerator = tokenGenerator;
    }

    @Autowired
    public void setRedisHelper(RedisHelper redisHelper) {
        this.redisHelper = redisHelper;
    }

    @Autowired
    public void setUserDetailManager(UserDetailManager userDetailManager) {
        this.userDetailManager = userDetailManager;
    }
}
